@@ -1,3 +1,5 @@
+from typing import Optional
+
 from wanikani_notifier.notifiers.notifier import Notifier, NoMessageProvided, factory
 
 
@@ -10,11 +12,15 @@ class ConsoleNotifier(Notifier):
     def key(cls) -> str:
         return "console"
 
-    def notify(self, title: str, message: str):
+    def notify(self, title: str, message: str, url: Optional[str] = None, icon: Optional[str] = None):
         if not message:
             raise NoMessageProvided
 
-        print(f"{title}: {message}")
+        notification = f"{title}:\n{message}"
+        if url:
+            notification += f"\n{url}"
+
+        print(notification)
 
 
 factory.register_builder(ConsoleNotifier.key(), ConsoleNotifier.build)
